==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafregional/kotlin/inputs/WebAclRuleOverrideActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafregional.kotlin.inputs

import com.pulumi.aws.wafregional.inputs.WebAclRuleOverrideActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property type Specifies how you want AWS WAF Regional to respond to requests that match the settings in a rule. Valid values for `action` are `ALLOW`, `BLOCK` or `COUNT`. Valid values for `override_action` are `COUNT` and `NONE`.
 */
public data class WebAclRuleOverrideActionArgs(
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.wafregional.inputs.WebAclRuleOverrideActionArgs> {
    override fun toJava(): com.pulumi.aws.wafregional.inputs.WebAclRuleOverrideActionArgs =
        com.pulumi.aws.wafregional.inputs.WebAclRuleOverrideActionArgs.builder()
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAclRuleOverrideActionArgs].
 */
@PulumiTagMarker
public class WebAclRuleOverrideActionArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    /**
     * @param value Specifies how you want AWS WAF Regional to respond to requests that match the settings in a rule. Valid values for `action` are `ALLOW`, `BLOCK` or `COUNT`. Valid values for `override_action` are `COUNT` and `NONE`.
     */
    @JvmName("kfykalkwbfmarlon")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Specifies how you want AWS WAF Regional to respond to requests that match the settings in a rule. Valid values for `action` are `ALLOW`, `BLOCK` or `COUNT`. Valid values for `override_action` are `COUNT` and `NONE`.
     */
    @JvmName("wqooskbojanksgwv")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): WebAclRuleOverrideActionArgs = WebAclRuleOverrideActionArgs(
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafregional/kotlin/inputs/WebAclRuleOverrideActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafregional.kotlin.inputs

import com.pulumi.aws.wafregional.inputs.WebAclRuleOverrideActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property type
 */
public data class WebAclRuleOverrideActionArgs(
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.wafregional.inputs.WebAclRuleOverrideActionArgs> {
    override fun toJava(): com.pulumi.aws.wafregional.inputs.WebAclRuleOverrideActionArgs =
        com.pulumi.aws.wafregional.inputs.WebAclRuleOverrideActionArgs.builder()
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebAclRuleOverrideActionArgs].
 */
@PulumiTagMarker
public class WebAclRuleOverrideActionArgsBuilder internal constructor() {
    private var type: Output<String>? = null

    /**
     * @param value
     */
    @JvmName("hyhknloygigwdeyi")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value
     */
    @JvmName("loqouqnlvgoydprc")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): WebAclRuleOverrideActionArgs = WebAclRuleOverrideActionArgs(
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
